==> oricli-0.1.20.tgz: package/index.js <==
#!/usr/bin/env node
var uuid=require('uuid')
var extract = require('extract-zip')
var fs = require('fs');
//var origami =require('origamicore')
const program = require('commander');  
const { prompt } = require('inquirer'); 
const { exec,spawn  } = require('child_process');
var scan = require('./scan');
var http = require('http');
var chokidar = require('chokidar');
var esprima = require('esprima');
var escodegen = require('escodegen');

var lastPackage=[]
var loadConfig=()=>{
    var config=eval(fs.readFileSync('./config.js')+'')
    return config
}
var saveConfig=(config)=>{
    fs.writeFileSync('./config.js','module.exports ='+JSON.stringify(config))
}
var runCommand=(command)=>{
    return new Promise((res,rej)=>{
            exec(command, (err, stdout, stderr) => {
              if (err) { 
                rej(err)
                return;
              }
              res(stdout)
              //console.log(stdout);
            }); 
    })
}
var install=(name,isGlobal)=>{
    return new Promise(async(res,rej)=>{
        //if(lastPackage.indexOf(name)>-1)
        //    return res()
        //lastPackage.push(name)
        try{ 

            var a =await runCommand(`node -e "require('${name}')"`)
            //console.log(`node -e "require('${name}')"`)
            res()
        }
        catch(exp)
        { 
            var x='npm install --save '
            if(isGlobal)
                x+= ' -g '
            console.log('install ->', name)    
            exec(x+name, (err, stdout, stderr) => {
              if (err) {
                //console.error(err);
                rej(err)
                return;
              }
              res()
              //console.log(stdout);
            });
        }
        
    })
}
var consoleColor={
    red:"\x1b[31m%s\x1b[0m",
    green:"\x1b[32m%s\x1b[0m",
    yellow:"\x1b[33m%s\x1b[0m",
    blue:"\x1b[34m%s\x1b[0m",
    white:"\x1b[37m%s\x1b[0m",
    cyan:"\x1b[36m%s\x1b[0m",
}
var read=(title)=>{
    return new Promise((resolve, reject)=>{
        prompt({type:'input',name:'value',message:title}).then(answers =>resolve(answers)); 
    })
}
global.read=read
var readString=async(title,items)=>{
    while(true)
    {
        var dt= await read(title)
        if(!dt.value)
            console.log(consoleColor.red,"worng data ,try again")  
         
        return dt.value
    }
} 
global.readString=readString

var choseItem=async(title,items)=>{
    while(true)
    {
        var dt= await read(title)
        if(items.indexOf(dt.value)==-1)
        {
            console.log(consoleColor.red,"worng name ,try again")  
            continue
        }
        return dt.value
    }
} 
global.choseItem=choseItem
var readInt=async(title,min=0,max=0)=>{
    while(true)
    {
        var dt= await read(title)
        try{
            var rt=parseInt(dt.value)
            if(isNaN(rt))
            { 
                console.log(consoleColor.red,"Enter number, try again") 
                continue
            }
            if(min && rt<min)
            {
                console.log(consoleColor.red,"min number is"+min+",try again")  
                continue
            }
            if(max && rt>max)
            {
                console.log(consoleColor.red,"max number is"+min+",try again")  
                continue
            }
        //console.log('######',rt)
            return rt
        }catch(exp){ 
            console.log(consoleColor.red,"Enter number, try again") 
        } 
        
    }
    
}
global.readInt=readInt
program
  .version('1.0.1')
  .description('origami core managment system');
  
program
  .command('help')
  .alias('a')
  .description('Add a contact')
  .action(async( ) => {  
     console.log('new           create new OrigamiCore project')
     console.log('')
     console.log('install       install pakages')
     console.log('')
     console.log('db            manage database config')
     console.log('')
     console.log('run           run project')
     console.log('')
     console.log('add           add config to project')
     console.log('')
  });



program
  .command('add')
  .alias('a')
  .description('Add a contact')
  .action(async( ) => {  
      try{
          
      process.stdout.write('\033c'); 
      new (require('./commands/add'))() 
      }catch(exp){
          console.log(exp)
      }
    // process.stdout.write('\033c');
    //  console.log('1->Express Endpoint')
    //  console.log('2->Socket Endpoint')
    //  console.log('3->Service')
    //  console.log('4->Module')
    //  console.log('5->Session Manager')
    //  console.log('6->Storage')
    //  console.log('7->UI')
    //  console.log('8->Database')
    //  var index = await read('enter number of item  : ')
    //  if(index.value==1)
    //  {
    //     createExpress()
    //  }
    //  if(index.value==2)
    //  {
    //     createSocket()
    //  }
    //  if(index.value==3)
    //  {
    //     createService()
    //  }
    //  if(index.value==4)
    //  {
    //     createModule()
    //  }
    //  if(index.value==8)
    //  {
    //     createDatabase()
    //  }
  });
 
program
  .command('new')
  .alias('a')
  .description('Add a contact')
  .action(async( ) => {  
      var name = await read('enter your project name : ')   
      var dir='./'+name.value
      if (fs.existsSync(dir))
      {
          console.log(new Error('the directory is exist.'))
          return
      }  
      var description = await read('enter your project description : ')  
      var pa={
          name:name.value,
          description:description.value,
          main:'index.js',
          bin:'./index.js',
          dependencies:{
              
          }
      }
      fs.mkdirSync(dir)
      fs.writeFileSync(dir+'/package.json',JSON.stringify(pa))
      fs.writeFileSync(dir+'/config.js','module.exports =[{id:"1",name:"baseclass"}]')
      fs.writeFileSync(dir+'/index.js','var origami=require("origamicore")\r\nglobal.path=__dirname\r\n'+
      'var config=require("./config.js")\r\nvar ori=new origami(config,()=>{  delete require.cache[require.resolve("./config.js")]; var r=require("./config.js"); return r})\r\nori.start()')
      console.log('Project Created')
  });
  
 
program
  .command('version')
  .alias('a')
  .description('Add a contact')
  .action(async( ) => {    
        console.log('oricli             0.1.12')
        try{
            var cmd=await runCommand(`node -e "var origami=require('origamicore');var server=new origami(require('./config.js'));console.log(server.getVersion())"`)
            console.log('origamicore        '+cmd)
        }catch(exp){
            //console.log('o origamicore not installed')
        }
        
        try{
            var origami=require('origamicore');
            var server=new origami(require('./config.js'));
            console.log('origamicore -g     '+server.getVersion()) 
        }catch(expp)
        {
            //console.log('origamicore not installed')
        }
        //console.log('origamicore    0.1.4')
  });
  
  
  

  
program
  .command('db')
  .alias('a')
  .description('Manage Database')
  .action(async( ) => {   
    var config=loadConfig()
     
    while(true)
    {
        var count=0
        var cons=null
        for(var a of config)
        {
            if(a.name=='database')
            {
                cons=a
                count=a.connection.length
            }
        }
        if(!cons)
        {
            var cons={name:'database',connection:[]}
            config.push(cons)
        }
        process.stdout.write('\033c');
        console.log('1->View Connection('+count+')')
        console.log('2->Add Connection')
        console.log('9->exit')
        var index = await read('enter number of item  : ')
        if(index.value=='9')
            break
        if(index.value=='1')
        {
            if(!cons)
            {
                console.log('No connection exist')
                var v = await read('do you want to add new connection ?(y/n)')
                if(v.value=='y'||v.value=='yes')
                    index.value='2' 
            }
            else
            {
                process.stdout.write('\033c');
                var c=0
                for(var a of cons.connection)
                {
                    console.log( c + '->'+a.name+'('+a.type+')')
                    c++                    
                }
                console.log('-1-> view all collection')
                while(true){
                    var select = await read('enter number of item  : ')
                    try
                    {
                        if(select.value==-1)
                            console.log(cons.connection)
                        else{
                            console.log(cons.connection[parseInt(select.value)])
                        }    
                        break
                    }catch(exp){
                        console.log('number is invalid')
                    }
                }
                await read('press any key to continue : ')
                

            }
        }
        if(index.value=='2')
        {
            var newcon={}
            while(true)
            {
                var vl = await read('enter you connection name  : ')
                if(cons && cons.connection)
                {
                    var f=cons.connection.filter(p=>p.name==vl.value)
                    if(f.length)
                    {
                        console.log('this name is exist . please enter other name ')
                        continue
                    }

                }
                    newcon.name=vl.value
                    break
            }
            while(true)
            {
                var vl = await read('enter you connection type  :(mongodb|mysql) ')
                if(vl.value!='mongodb' &&vl.value!='mysql' )
                {
                    console.log('your type is wrong')
                    continue
                }
                newcon.type=vl.value
                break
            }
            var vl1 = await read('enter your connection host (like 55.0.0.21 or locahost)  : ')
            newcon.host=vl1.value
             
            vl1 = await read('enter your connection database name  : ')
            newcon.database=vl1.value
             
            vl1 = await read('enter your connection database username  : ')
            if(vl1.value)
                newcon.username=vl1.value
             
            vl1 = await read('enter your connection database password  : ')
            if(vl1.value)
                newcon.password=vl1.value
            
            vl1 = await read('do you want to use repliction  ?(y/n) ')
            if(vl1.value=='y'||vl1.value=='yes')
            {
                newcon.replicate={}
                 vl1 = await read('enter your repliction host (like 55.0.0.21 or locahost)  : ')
                 newcon.replicate.host=vl1.value 
                 vl1 = await read('enter your repliction port  : ')
                 newcon.replicate.port=vl1.value 
                 vl1 = await read('enter your repliction name  : ')
                 newcon.replicate.name=vl1.value 
                 vl1 = await read('enter your repliction database name  : ')
                 newcon.replicate.database=vl1.value
                 vl1 = await read('enter your repliction database username  : ')
                 newcon.replicate.username=vl1.value
                 vl1 = await read('enter your repliction database password  : ')
                 newcon.replicate.password=vl1.value
                
            } 
            cons.connection.push(newcon)
            saveConfig(config)
        }
        
    }
      
  });
  var download=(url,name,path)=>{
      return new Promise((res,rej)=>{
        var request = http.get(url, function(response) { 
            if(response.statusMessage=='OK')
            {
                var file = fs.createWriteStream(name);
                response.pipe(file,()=>{});
                extract(name, {dir: path}, function (err) {
                    if(err) console.log('errrrr-->',err)
                    fs.unlink(name,()=>{})
                    res(response)
                    
                   })
                return
            }  
            rej(response)
          });
        
      })
  }
  var installPackage= (name)=>{
      return new Promise(async(res,rej)=>{
          //console.log('1')
            try{
                    if(fs.existsSync('./origami-modules/'+name))
                        return res(true)
                    //var a= await download('http://www.origamicore.com/packages/'+name+'/'+name+'.zip','./origami-modules/'+name+'.zip',process.cwd()+'/origami-modules/')
                    var a= await download('http://localhost/packages/'+name+'/'+name+'.zip','./origami-modules/'+name+'.zip',process.cwd()+'/origami-modules/')
                    console.log('Installed',name)
                    res(true)
            }catch(exp){
                console.log( "\x1b[31m%s\x1b[0m",name+' not found')
                rej(exp)
            }
      })
  }
  global.installPackage=installPackage
  var installProject=async()=>
  {
    if(!fs.existsSync('./config.js'))
    {
        console.log('config file is not exist')
        return
    }

    try{ 
        await install ('origamicore')
        await install ('chokidar')
        var cmd1=await runCommand(`node -e "var origami=require('origamicore');var server=new origami(require('./config.js'));console.log(server.geInternaltPackages())"`)
        //console.log(cmd1)
        if(!fs.existsSync('./origami-modules'))
        {
            fs.mkdirSync('./origami-modules')
        }
        while(cmd1.indexOf('\'')>-1)
        {
            cmd1=cmd1.replace('\'','"')
        }
        var ipgs = JSON.parse(cmd1)
        console.log(ipgs)
        for(var a of ipgs)
        {
            try{
                await installPackage(a)

            }catch(exp){
        console.log(exp)

            }
        //console.log(a)
        }
        //await install ('origamicore')
        //await install ('chokidar')

        var cmd=await runCommand(`node -e "var origami=require('origamicore');var server=new origami(require('./config.js'));console.log(server.getPackages())"`)
        
        //console.log(cmd)
        while(cmd.indexOf('\'')>-1)
        {
            cmd=cmd.replace('\'','"')
        } 

        var pgs = JSON.parse(cmd)//server.getPackages()
        
        for(var a of pgs)
        { 
            try{
            var pa = fs.existsSync('./node_modules/'+a)
            if(!pa)
                    await install (a)
            }catch(exp){
                console.log(exp)
            }
        }
        console.log('finish')
    }catch(exp){
        console.log(exp)
    }
  }
program
  .command('install')
  .alias('a')
  .description('install project')
  .action(async( ) => {   
    installProject()
    //console.log({firstname, lastname, phone, email}); 
  });
  


program
  .command('run')
  .alias('a')
  .description('run project')
  .action(async() => {  
      console.log('installing package ...')
      await installProject() 
      console.log('run project ...')
    const child =  exec('node index');
    child.on('exit', function (code, signal) {
        console.log('child process exited with ' +
                    `code ${code} and signal ${signal}`);
      });
      child.stdout.on('data', (data) => {
        console.log(`---->\n${data}`);
      });
      
      child.stderr.on('data', (data) => {
        console.error(`!!!!!!!!!!!!!!!!:\n${data}`);
      });
    //console.log(scan('.', 'files'))
    // console.log(__dirname)
    //var or=require('node require("origamicore")')
     
    
  });

var runProccess=(syntax , onExit,onData,onError)=>
{
    const child =  exec(syntax, {async:true});

    child.on('exit', onExit );
    child.stdout.on('data', onData);
      
      child.stderr.on('data',onError ); 
    return   child
}  

program
  .command('live')
  .alias('a')
  .description('run project')
  .action(async() => {  
        console.log('installing package ...')
        await installProject() 
        console.log('run project ...')
        
    var proc =  null
    var drun=new Date()
    var state=1
    var tempstate=1
    fs.writeFileSync('livelog.txt','')
    proc = runProccess('node index',
        (code, signal)=> {
            console.log('child process exited with ' +
                        `code ${code} and signal ${signal}`);
        },
        (data) => {
            console.log(`---->\n${data}`);
        },
        (data) => {
            console.error(`!!!!!!!!!!!!!!!!:\n${data}`);
        }
    )
    setInterval(async()=>{
        if(state!==tempstate)
        {
            tempstate=state
            await installProject() 
            console.log(consoleColor.blue,'Reload Project')
            fs.writeFileSync('livelog.txt',state)
            
            //console.log('')
            // if(proc)
            //     proc.kill(2)
            // proc = runProccess('node index',
            //     (code, signal)=> {
            //         console.log('child process exited with ' +
            //                     `code ${code} and signal ${signal}`);
            //     },
            //     (data) => {
            //         console.log(`---->\n${data}`);
            //     },
            //     (data) => {
            //         console.error(`!!!!!!!!!!!!!!!!:\n${data}`);
            //     }
            // )
        }
    },1000)
        fs.writeFileSync('livelog.txt','')
        var watcher = chokidar.watch(process.cwd(), {ignored:/node_modules|\.git|livelog.txt|package.json|package-lock.json/, persistent: true});
        watcher
        .on('add', function(path, stats) {
            console.log()
                if(stats.birthtime>drun)
                {
                    //console.log(path);
                    state++
                }
                     
            }
        )
        .on('change', function(path) { state++})
        .on('unlink', function(path) { state++})
        .on('error', function(error) {console.error('Error happened', error);})
  });




program.parse(process.argv);

==> oricli-1.0.0.tgz: package/index.js <==
#!/usr/bin/env node
var uuid=require('uuid')
var extract = require('extract-zip')
var fs = require('fs');
//var origami =require('origamicore')
const program = require('commander');  
const { prompt } = require('inquirer'); 
const { exec,spawn  } = require('child_process');
require("./global.js")
var scan = require('./scan');
var http = require('http');
var chokidar = require('chokidar');
var esprima = require('esprima');
var escodegen = require('escodegen');
var help=require("./commands/help.js")
var install =require("./commands/install.js")
var lastPackage=[]
var newProj=require("./commands/newProject")
var loadConfig=()=>{
    var config=eval(fs.readFileSync('./config.js')+'')
    return config
}
var saveConfig=(config)=>{
    fs.writeFileSync('./config.js','module.exports ='+JSON.stringify(config))
}
 
global.projectPath=process.cwd(); 
program.version('1.0.1').description('origami core managment system'); 
program.command('help').alias('a').description('help').action(async( ) => {help.viewHelp();}); 
program.command('add').alias('a').description('Add a service')
  .action(async( ) => {  
      try{ 
        new (require('./commands/add'))() 
      }catch(exp){
          console.log(exp)
      }
    
  });
 
program.command('new').alias('a').description('Add a contact')
  .action(async( ) => {  
    newProj.create()
       
  });
  
 
program.command('version').alias('v').description('get version')
  .action(async( ) => {    
    help.getVersion()
  });
  
  
  

  
program
  .command('db')
  .alias('a')
  .description('Manage Database')
  .action(async( ) => {   
    var config=loadConfig()
     
    while(true)
    {
        var count=0
        var cons=null
        for(var a of config)
        {
            if(a.name=='database')
            {
                cons=a
                count=a.connection.length
            }
        }
        if(!cons)
        {
            var cons={name:'database',connection:[]}
            config.push(cons)
        }
        process.stdout.write('\033c');
        console.log('1->View Connection('+count+')')
        console.log('2->Add Connection')
        console.log('9->exit')
        var index = await read('enter number of item  : ')
        if(index.value=='9')
            break
        if(index.value=='1')
        {
            if(!cons)
            {
                console.log('No connection exist')
                var v = await read('do you want to add new connection ?(y/n)')
                if(v.value=='y'||v.value=='yes')
                    index.value='2' 
            }
            else
            {
                process.stdout.write('\033c');
                var c=0
                for(var a of cons.connection)
                {
                    console.log( c + '->'+a.name+'('+a.type+')')
                    c++                    
                }
                console.log('-1-> view all collection')
                while(true){
                    var select = await read('enter number of item  : ')
                    try
                    {
                        if(select.value==-1)
                            console.log(cons.connection)
                        else{
                            console.log(cons.connection[parseInt(select.value)])
                        }    
                        break
                    }catch(exp){
                        console.log('number is invalid')
                    }
                }
                await read('press any key to continue : ')
                

            }
        }
        if(index.value=='2')
        {
            var newcon={}
            while(true)
            {
                var vl = await read('enter you connection name  : ')
                if(cons && cons.connection)
                {
                    var f=cons.connection.filter(p=>p.name==vl.value)
                    if(f.length)
                    {
                        console.log('this name is exist . please enter other name ')
                        continue
                    }

                }
                    newcon.name=vl.value
                    break
            }
            while(true)
            {
                var vl = await read('enter you connection type  :(mongodb|mysql) ')
                if(vl.value!='mongodb' &&vl.value!='mysql' )
                {
                    console.log('your type is wrong')
                    continue
                }
                newcon.type=vl.value
                break
            }
            var vl1 = await read('enter your connection host (like 55.0.0.21 or locahost)  : ')
            newcon.host=vl1.value
             
            vl1 = await read('enter your connection database name  : ')
            newcon.database=vl1.value
             
            vl1 = await read('enter your connection database username  : ')
            if(vl1.value)
                newcon.username=vl1.value
             
            vl1 = await read('enter your connection database password  : ')
            if(vl1.value)
                newcon.password=vl1.value
            
            vl1 = await read('do you want to use repliction  ?(y/n) ')
            if(vl1.value=='y'||vl1.value=='yes')
            {
                newcon.replicate={}
                 vl1 = await read('enter your repliction host (like 55.0.0.21 or locahost)  : ')
                 newcon.replicate.host=vl1.value 
                 vl1 = await read('enter your repliction port  : ')
                 newcon.replicate.port=vl1.value 
                 vl1 = await read('enter your repliction name  : ')
                 newcon.replicate.name=vl1.value 
                 vl1 = await read('enter your repliction database name  : ')
                 newcon.replicate.database=vl1.value
                 vl1 = await read('enter your repliction database username  : ')
                 newcon.replicate.username=vl1.value
                 vl1 = await read('enter your repliction database password  : ')
                 newcon.replicate.password=vl1.value
                
            } 
            cons.connection.push(newcon)
            saveConfig(config)
        }
        
    }
      
  });
  var installPackage= (name)=>{
    //   return new Promise(async(res,rej)=>{
    //       //console.log('1')
    //         try{
    //                 if(fs.existsSync('./origami-modules/'+name))
    //                     return res(true)
    //                 //var a= await download('http://www.origamicore.com/packages/'+name+'/'+name+'.zip','./origami-modules/'+name+'.zip',process.cwd()+'/origami-modules/')
    //                 var a= await global.download('http://localhost/packages/'+name+'/'+name+'.zip','./origami-modules/'+name+'.zip',global.projectPath+'/origami-modules/')
    //                 console.log('Installed',name)
    //                 res(true)
    //         }catch(exp){
    //             console.log( "\x1b[31m%s\x1b[0m",name+' not found')
    //             rej(exp)
    //         }
    //   })
  }
  global.installPackage=installPackage

  var getConfig = async()=>{
    if(!fs.existsSync('./config.js'))
    { 
         throw "config file is not exist"
    }
    
  }

  var installProject=async()=>
  {
    if(!fs.existsSync('./config.js'))
    {
        console.log('config file is not exist')
        return
    }

    try{ 
        await install ('origamicore')
        await install ('chokidar')
        var cmd1=await global.runCommand(`node -e "var origami=require('origamicore');var server=new origami(require('./config.js'));console.log(server.geInternaltPackages())"`)
        //console.log(cmd1)
        if(!fs.existsSync('./origami-modules'))
        {
            fs.mkdirSync('./origami-modules')
        }
        while(cmd1.indexOf('\'')>-1)
        {
            cmd1=cmd1.replace('\'','"')
        }
        var ipgs = JSON.parse(cmd1)
        console.log(ipgs)
        for(var a of ipgs)
        {
            try{
                await installPackage(a)

            }catch(exp){
        console.log(exp)

            }
        //console.log(a)
        }
        //await install ('origamicore')
        //await install ('chokidar')

        var cmd=await global.runCommand(`node -e "var origami=require('origamicore');var server=new origami(require('./config.js'));console.log(server.getPackages())"`)
        
        //console.log(cmd)
        while(cmd.indexOf('\'')>-1)
        {
            cmd=cmd.replace('\'','"')
        } 

        var pgs = JSON.parse(cmd)//server.getPackages()
        
        for(var a of pgs)
        { 
            try{
            var pa = fs.existsSync('./node_modules/'+a)
            if(!pa)
                    await install (a)
            }catch(exp){
                console.log(exp)
            }
        }
        console.log('finish')
    }catch(exp){
        console.log(exp)
    }
  }
program
  .command('install')
  .alias('a')
  .description('install project')
  .action(async( ) => {   
    installProject()
    //console.log({firstname, lastname, phone, email}); 
  });
  


program
  .command('run')
  .alias('a')
  .description('run project')
  .action(async() => {  
      console.log('installing package ...')
      await installProject() 
      console.log('run project ...')
    const child =  exec('node index');
    child.on('exit', function (code, signal) {
        console.log('child process exited with ' +
                    `code ${code} and signal ${signal}`);
      });
      child.stdout.on('data', (data) => {
        console.log(`---->\n${data}`);
      });
      
      child.stderr.on('data', (data) => {
        console.error(`!!!!!!!!!!!!!!!!:\n${data}`);
      });
    //console.log(scan('.', 'files'))
    // console.log(__dirname)
    //var or=require('node require("origamicore")')
     
    
  });

var runProccess=(syntax , onExit,onData,onError)=>
{
    const child =  exec(syntax, {async:true});

    child.on('exit', onExit );
    child.stdout.on('data', onData);
      
      child.stderr.on('data',onError ); 
    return   child
}  

program
  .command('cluster')
  .alias('a')
  .description('run cluster')
  .action(async() => {  
    console.log('installing package ...')
    await installProject() 
    console.log('run project ...')

  })
program
  .command('live')
  .alias('a')
  .description('run project')
  .action(async() => {  
        console.log('installing package ...')
        await installProject() 
        console.log('run project ...')
        
    var proc =  null
    var drun=new Date()
    var state=1
    var tempstate=1
    fs.writeFileSync('livelog.txt','')
    proc = runProccess('node index',
        (code, signal)=> {
            console.log('child process exited with ' +
                        `code ${code} and signal ${signal}`);
        },
        (data) => {
            console.log(`---->\n${data}`);
        },
        (data) => {
            console.error(`!!!!!!!!!!!!!!!!:\n${data}`);
        }
    )
    setInterval(async()=>{
        if(state!==tempstate)
        {
            tempstate=state
            await installProject() 
            console.log("info",'Reload Project')
            fs.writeFileSync('livelog.txt',state)
            
            //console.log('')
            // if(proc)
            //     proc.kill(2)
            // proc = runProccess('node index',
            //     (code, signal)=> {
            //         console.log('child process exited with ' +
            //                     `code ${code} and signal ${signal}`);
            //     },
            //     (data) => {
            //         console.log(`---->\n${data}`);
            //     },
            //     (data) => {
            //         console.error(`!!!!!!!!!!!!!!!!:\n${data}`);
            //     }
            // )
        }
    },1000)
        fs.writeFileSync('livelog.txt','')
        var watcher = chokidar.watch(process.cwd(), {ignored:/node_modules|\.git|livelog.txt|package.json|package-lock.json/, persistent: true});
        watcher
        .on('add', function(path, stats) {
            console.log()
                if(stats.birthtime>drun)
                {
                    //console.log(path);
                    state++
                }
                     
            }
        )
        .on('change', function(path) { state++})
        .on('unlink', function(path) { state++})
        .on('error', function(error) {console.error('Error happened', error);})
  });




program.parse(process.argv);
